"""
# rtree

Rtree provides Python bindings to libspatialindex for quick
hyperrectangular intersection queries.
"""

from __future__ import annotations

__version__ = "1.3.0"

from .index import Index, Rtree  # noqa
